==> aws-sdk-cpp-1.9.365-2-x86_64.pkg.tar.zst: usr/include/aws/email/model/ReceiptIpFilter.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/email/SES_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSStreamFwd.h>
#include <aws/email/model/ReceiptFilterPolicy.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Xml
{
  class XmlNode;
} // namespace Xml
} // namespace Utils
namespace SES
{
namespace Model
{

  /**
   * <p>A receipt IP address filter enables you to specify whether to accept or
   * reject mail originating from an IP address or range of IP addresses.</p> <p>For
   * information about setting up IP address filters, see the <a
   * href="https://docs.aws.amazon.com/ses/latest/DeveloperGuide/receiving-email-ip-filters.html">Amazon
   * SES Developer Guide</a>.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/email-2010-12-01/ReceiptIpFilter">AWS
   * API Reference</a></p>
   */
  class AWS_SES_API ReceiptIpFilter
  {
  public:
    ReceiptIpFilter();
    ReceiptIpFilter(const Aws::Utils::Xml::XmlNode& xmlNode);
    ReceiptIpFilter& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);

    void OutputToStream(Aws::OStream& ostream, const char* location, unsigned index, const char* locationValue) const;
    void OutputToStream(Aws::OStream& oStream, const char* location) const;


    /**
     * <p>Indicates whether to block or allow incoming mail from the specified IP
     * addresses.</p>
     */
    inline const ReceiptFilterPolicy& GetPolicy() const{ return m_policy; }

    /**
     * <p>Indicates whether to block or allow incoming mail from the specified IP
     * addresses.</p>
     */
    inline bool PolicyHasBeenSet() const { return m_policyHasBeenSet; }

    /**
     * <p>Indicates whether to block or allow incoming mail from the specified IP
     * addresses.</p>
     */
    inline void SetPolicy(const ReceiptFilterPolicy& value) { m_policyHasBeenSet = true; m_policy = value; }

    /**
     * <p>Indicates whether to block or allow incoming mail from the specified IP
     * addresses.</p>
     */
    inline void SetPolicy(ReceiptFilterPolicy&& value) { m_policyHasBeenSet = true; m_policy = std::move(value); }

    /**
     * <p>Indicates whether to block or allow incoming mail from the specified IP
     * addresses.</p>
     */
    inline ReceiptIpFilter& WithPolicy(const ReceiptFilterPolicy& value) { SetPolicy(value); return *this;}

    /**
     * <p>Indicates whether to block or allow incoming mail from the specified IP
     * addresses.</p>
     */
    inline ReceiptIpFilter& WithPolicy(ReceiptFilterPolicy&& value) { SetPolicy(std::move(value)); return *this;}


    /**
     * <p>A single IP address or a range of IP addresses that you want to block or
     * allow, specified in Classless Inter-Domain Routing (CIDR) notation. An example
     * of a single email address is 10.0.0.1. An example of a range of IP addresses is
     * 10.0.0.1/24. For more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline const Aws::String& GetCidr() const{ return m_cidr; }

    /**
     * <p>A single IP address or a range of IP addresses that you want to block or
     * allow, specified in Classless Inter-Domain Routing (CIDR) notation. An example
     * of a single email address is 10.0.0.1. An example of a range of IP addresses is
     * 10.0.0.1/24. For more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline bool CidrHasBeenSet() const { return m_cidrHasBeenSet; }

    /**
     * <p>A single IP address or a range of IP addresses that you want to block or
     * allow, specified in Classless Inter-Domain Routing (CIDR) notation. An example
     * of a single email address is 10.0.0.1. An example of a range of IP addresses is
     * 10.0.0.1/24. For more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline void SetCidr(const Aws::String& value) { m_cidrHasBeenSet = true; m_cidr = value; }

    /**
     * <p>A single IP address or a range of IP addresses that you want to block or
     * allow, specified in Classless Inter-Domain Routing (CIDR) notation. An example
     * of a single email address is 10.0.0.1. An example of a range of IP addresses is
     * 10.0.0.1/24. For more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline void SetCidr(Aws::String&& value) { m_cidrHasBeenSet = true; m_cidr = std::move(value); }

    /**
     * <p>A single IP address or a range of IP addresses that you want to block or
     * allow, specified in Classless Inter-Domain Routing (CIDR) notation. An example
     * of a single email address is 10.0.0.1. An example of a range of IP addresses is
     * 10.0.0.1/24. For more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline void SetCidr(const char* value) { m_cidrHasBeenSet = true; m_cidr.assign(value); }

    /**
     * <p>A single IP address or a range of IP addresses that you want to block or
     * allow, specified in Classless Inter-Domain Routing (CIDR) notation. An example
     * of a single email address is 10.0.0.1. An example of a range of IP addresses is
     * 10.0.0.1/24. For more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline ReceiptIpFilter& WithCidr(const Aws::String& value) { SetCidr(value); return *this;}

    /**
     * <p>A single IP address or a range of IP addresses that you want to block or
     * allow, specified in Classless Inter-Domain Routing (CIDR) notation. An example
     * of a single email address is 10.0.0.1. An example of a range of IP addresses is
     * 10.0.0.1/24. For more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline ReceiptIpFilter& WithCidr(Aws::String&& value) { SetCidr(std::move(value)); return *this;}

    /**
     * <p>A single IP address or a range of IP addresses that you want to block or
     * allow, specified in Classless Inter-Domain Routing (CIDR) notation. An example
     * of a single email address is 10.0.0.1. An example of a range of IP addresses is
     * 10.0.0.1/24. For more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline ReceiptIpFilter& WithCidr(const char* value) { SetCidr(value); return *this;}

  private:

    ReceiptFilterPolicy m_policy;
    bool m_policyHasBeenSet = false;

    Aws::String m_cidr;
    bool m_cidrHasBeenSet = false;
  };

} // namespace Model
} // namespace SES
} // namespace Aws

==> aws-sdk-cpp-1.11.476-1-x86_64.pkg.tar.zst: usr/include/aws/email/model/ReceiptIpFilter.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/email/SES_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSStreamFwd.h>
#include <aws/email/model/ReceiptFilterPolicy.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Xml
{
  class XmlNode;
} // namespace Xml
} // namespace Utils
namespace SES
{
namespace Model
{

  /**
   * <p>A receipt IP address filter enables you to specify whether to accept or
   * reject mail originating from an IP address or range of IP addresses.</p> <p>For
   * information about setting up IP address filters, see the <a
   * href="https://docs.aws.amazon.com/ses/latest/dg/receiving-email-ip-filtering-console-walkthrough.html">Amazon
   * SES Developer Guide</a>.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/email-2010-12-01/ReceiptIpFilter">AWS
   * API Reference</a></p>
   */
  class ReceiptIpFilter
  {
  public:
    AWS_SES_API ReceiptIpFilter();
    AWS_SES_API ReceiptIpFilter(const Aws::Utils::Xml::XmlNode& xmlNode);
    AWS_SES_API ReceiptIpFilter& operator=(const Aws::Utils::Xml::XmlNode& xmlNode);

    AWS_SES_API void OutputToStream(Aws::OStream& ostream, const char* location, unsigned index, const char* locationValue) const;
    AWS_SES_API void OutputToStream(Aws::OStream& oStream, const char* location) const;


    ///@{
    /**
     * <p>Indicates whether to block or allow incoming mail from the specified IP
     * addresses.</p>
     */
    inline const ReceiptFilterPolicy& GetPolicy() const{ return m_policy; }
    inline bool PolicyHasBeenSet() const { return m_policyHasBeenSet; }
    inline void SetPolicy(const ReceiptFilterPolicy& value) { m_policyHasBeenSet = true; m_policy = value; }
    inline void SetPolicy(ReceiptFilterPolicy&& value) { m_policyHasBeenSet = true; m_policy = std::move(value); }
    inline ReceiptIpFilter& WithPolicy(const ReceiptFilterPolicy& value) { SetPolicy(value); return *this;}
    inline ReceiptIpFilter& WithPolicy(ReceiptFilterPolicy&& value) { SetPolicy(std::move(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>A single IP address or a range of IP addresses to block or allow, specified
     * in Classless Inter-Domain Routing (CIDR) notation. An example of a single email
     * address is 10.0.0.1. An example of a range of IP addresses is 10.0.0.1/24. For
     * more information about CIDR notation, see <a
     * href="https://tools.ietf.org/html/rfc2317">RFC 2317</a>.</p>
     */
    inline const Aws::String& GetCidr() const{ return m_cidr; }
    inline bool CidrHasBeenSet() const { return m_cidrHasBeenSet; }
    inline void SetCidr(const Aws::String& value) { m_cidrHasBeenSet = true; m_cidr = value; }
    inline void SetCidr(Aws::String&& value) { m_cidrHasBeenSet = true; m_cidr = std::move(value); }
    inline void SetCidr(const char* value) { m_cidrHasBeenSet = true; m_cidr.assign(value); }
    inline ReceiptIpFilter& WithCidr(const Aws::String& value) { SetCidr(value); return *this;}
    inline ReceiptIpFilter& WithCidr(Aws::String&& value) { SetCidr(std::move(value)); return *this;}
    inline ReceiptIpFilter& WithCidr(const char* value) { SetCidr(value); return *this;}
    ///@}
  private:

    ReceiptFilterPolicy m_policy;
    bool m_policyHasBeenSet = false;

    Aws::String m_cidr;
    bool m_cidrHasBeenSet = false;
  };

} // namespace Model
} // namespace SES
} // namespace Aws
